@@ -9,22 +9,36 @@ DEFAULT_MODEL = LGBMClassifier
 
 
 class AdHocBoost:
+    """
+    AdHocBoost classifier, a model specialized for binary classification in a severely imbalanced-class scenario.
+
+    The AdHocBoost model works by creating n sequential LGBM classifiers. The first n-1 classifiers can most aptly be
+    thought of as dataset filtering models, i.e. each one does a good job at classifying rows as "definitely not the
+    positive class" versus "maybe the positive class". The nth model only works on this filtered "maybe positive" data.
+
+    :param number_stages: The number of stages in the model.
+    :type number_stages: int
+    :param stage_model_cls: The model class to use for the individual stages' classifiers.
+    :type stage_model_cls: Any sklearn-like class with `.fit()`, `.predict()`, and `predict_proba()` implemented.
+    :param stage_model_hyper_param_sets: List of dictionaries, where the nth element of the list corresponds to the
+        hyperparameters for the nth classifier
+    :type stage_model_hyper_param_sets: list<dict<>>
+    :param stage_proba_thresholds: List of probability thresholds for each stage's model, where the nth element of the
+        list corresponds to the probability threshold applied to the nth classifier's predicted-probabilities.
+    :type stage_proba_thresholds: list<float>
+    :param stage_positive_sample_weights: List of positive sample weights for each stage's classifier, where the nth
+        element of the list corresponds to the positive sample weight applied to the data for the nth classifier during
+        training.
+        With this, the nth classifier gets trained with the class weights {False: 1, True: positive_sample_weight[n]}
+    :type stage_positive_sample_weights: list<float>
+    """
 
     def __init__(self, number_stages=2, stage_model_cls=DEFAULT_MODEL,
                  stage_model_hyper_param_sets=None, stage_proba_thresholds=None,
                  stage_positive_sample_weights=None):
         """
         Init function.
-        :param number_stages: The number of stages in the model.
-        :type number_stages: int
-        :param stage_model_cls: The model class to use for each stage's model.
-        :type stage_model_cls: Any sklearn-like class with `.fit()`, `.predict()`, and `predict_proba()` implemented.
-        :param stage_model_hyper_param_sets: List of dictionaries containing the hyperparameters for each model.
-        :type stage_model_hyper_param_sets: list<dict<>>
-        :param stage_proba_thresholds: List of probability thresholds for each stage's model.
-        :type stage_proba_thresholds: list<float>
-        :param sample_weight_multiplier: A scalar constant for multiplying class weights
-        :type sample_weight_multiplier: float
+
         """
 
         # Load default parameters if necessary.
@@ -78,12 +92,12 @@ class AdHocBoost:
         Examples:
             >>> config_dict = {
                 'number_stages': 2,
-                'model_0__sample_weight_multiplier': 0.17,
+                'model_0__positive_sample_weight': 0.17,
                 'model_0__learning_rate': 0.1,
                 'model_0__num_leaves': 30,
                 'model_0__min_data_in_leaf': 17,
                 'stage_0__proba_threshold': 0.2,
-                'model_1__sample_weight_multiplier': 0.10,
+                'model_1__positive_sample_weight': 0.10,
                 'model_1__learning_rate': 0.05,
                 'model_1__num_leaves': 26,
                 'model_1__min_data_in_leaf': 15,
@@ -91,7 +105,7 @@ class AdHocBoost:
             >>> preprocessed_config_dict = AdHocBoost.preprocess_config(config_dict)
             >>> print(preprocessed_config_dict)
             {'number_stages': 2,
-             'sample_weight_multipliers': [0.17, 0.1],
+             'stage_positive_sample_weights': [0.17, 0.1],
              'stage_model_hyper_param_sets': [{'learning_rate': 0.1,
                                                'min_data_in_leaf': 17,
                                                'num_leaves': 30},
@@ -159,7 +173,6 @@ class AdHocBoost:
         # Create a dataframe for tracking the predicted probability of each model.
         logging.info(f"Fitting entire model pipeline.")
         stage_prediction_df = pd.DataFrame({
-            # f"stage{stage_number}": np.zeros(len(train_X))
             f"stage{stage_number}": np.zeros(train_X.shape[0])
             for stage_number in range(self.number_stages)})
 
